package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````#"````````!``````````/"Q````
M````!0```$``.``+`$``&P`:``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```#,`@``````
M`,P"````````S`(````````A`````````"$``````````0`````````#``!P
M!````':P`````````````````````````````&8````````````````````!
M``````````$````%````````````````````````````````````P)L`````
M``#`FP`````````0`````````0````8```"8JP```````)BK````````F*L`
M``````"X!````````.`$`````````!`````````"````!@```+"K````````
ML*L```````"PJP```````!`"````````$`(````````(``````````0````$
M````J`(```````"H`@```````*@"````````)``````````D``````````0`
M````````!`````0```"TF@```````+2:````````M)H````````,`0``````
M``P!````````!`````````!0Y71D!````"B2````````*)(````````HD@``
M`````.P`````````[``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``"8JP```````)BK````````F*L```````!H!````````&@$`````````0``
M```````$````%`````,```!'3E4`!^1!IRO*L*`0:1OF@;D'?0DB\$8O;&EB
M+VQD+6QI;G5X+7)I<V-V-C0M;'`V-&0N<V\N,0`````1````1P````0````(
M````()`0`05`!,0H`@$$@(8$A(*)``()(`0(B(`00;H``H@`````1P```$H`
M``!-````3@```%8```!7````60```%L```!<````70```%\```!A````8@``
M`&0``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!
ML@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#FVL)0]9FK\QF&7X*AT)%U>R)
M!W#3<U"?V#-BV^T^S])L%8PES`PZEPO_8?)A?ZF<F^"G`@IK&IY0H^#[20``
M`````````````````````````````````````````P`+`&`>````````````
M``````#G`@``$0````````````````````````#5````$@``````````````
M``````````#%`0``$@````````````````````````##`@``$@``````````
M``````````````"'````$@````````````````````````!.`0``$@``````
M``````````````````"6`@``$@````````````````````````#,`0``$@``
M``````````````````````!E`0``$@````````````````````````"5`0``
M$@````````````````````````#K````$@````````````````````````"R
M`@``$@````````````````````````#-`@``$0``````````````````````
M``"=`@``$@````````````````````````"(`0``$@``````````````````
M```````<`0``$@`````````````````````````,`0``$@``````````````
M``````````#^````$@````````````````````````#Q`0``$@``````````
M``````````````#3`0``$@````````````````````````"^`0``$@``````
M``````````````````#5`@``$@`````````````````````````!````(```
M```````````````````````'`@``$@````````````````````````!L`0``
M$@`````````````````````````=````(`````````````````````````!#
M`@``$@````````````````````````"F`0``$@``````````````````````
M```W````$@````````````````````````"D`@``$@``````````````````
M``````#+`@``$0````````````````````````!4````%@``````````````
M`````````````@``$@`````````````````````````^`0``$@``````````
M``````````````"K`@``$@`````````````````````````F`@``$@``````
M``````````````````!G````$@````````````````````````"``@``$@``
M``````````````````````#$````$@````````````````````````!X````
M$@````````````````````````"-`0``$@````````````````````````"H
M````$@````````````````````````#:````$@``````````````````````
M``!Y`@``$@````````````````````````#K`0``$@``````````````````
M```````P`0``$@````````````````````````"?`0``$@``````````````
M``````````!C`@``$@````````````````````````!<`@``$0``````````
M``````````````#?````$@````````````````````````"V`0``$@``````
M``````````````````!"`@``$@````````````````````````!J`@``(@``
M``````````````````````"3````$@`````````````````````````0`@``
M$@````````````````````````#9`0``$@````````````````````````"'
M`@``$@````````````````````````!9`0``$@``````````````````````
M```T`@``$@````````````````````````"O`P``$@``````````````````
M``````"W````$0`````````````````````````8`@``$@``````````````
M```````````E`0``$@````````````````````````!%````$@``````````
M``````````````!*`@``$@````````````````````````".`@``$@``````
M``````````````````#>`0``$@````````````````````````!W`0``$@``
M``````````````````````"O`0``$@````````````````````````"X`P``
M$@`+`$@W````````M@````````!*!```$@`+`%@P````````+@4```````!7
M`@``$@`+`&`>````````J@$````````O`P``$@`+`#(G````````$```````
M``!-`P``$@`+`(8U````````P@$```````!P!```$@`+`$(G````````M`$`
M```````P!```$``7`%"P``````````````````!``P``$@`+`/8H````````
M*`````````!C`P``$@`+`+8M````````6@````````#0`P``$0`,`+!0````
M````!``````````-!```$@`+`-I-`````````@$````````H!```$@`+`$(F
M````````-@````````!%!```$``7`'BP``````````````````!>!```$@`+
M`(8O````````T@````````"'!```$@`+`!`N````````5`````````#?`P``
M$``6``"P``````````````````"'`P``$@`+`!XI````````\@````````#[
M`P``$`#Q_P"X``````````````````!7!```$``6`%"P````````````````
M``!]!```$0`6`$BP````````"``````````8!```$``6`%"P````````````
M``````#E`P``$@`+``P@````````(@````````#L`P``$``6``"P````````
M```````````\!```$@`+`'Y-````````7`````````#A`P``(``6``"P````
M``````````````#$`P``$``7`'BP``````````````````"=`P``$@`+`&HO
M````````'`````````!Q`P``$@`+`'@F````````N@````````"3`P``$@`+
M`-Q.````````N@$```````"/!```$@`+`!`J````````I@,`````````7TE4
M35]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT
M7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!0
M3%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M
M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`
M<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D
M9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!S
M=')T;VL`<W1R;&5N`')M9&ER`')E860`7U]M96UC<'E?8VAK`&UK9&ER`%]?
M=F9P<FEN=&9?8VAK`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT
M9E]C:&L`7U]M96UM;W9E7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L
M:6)C7W-T87)T7VUA:6X`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S
M=')C:'(`;65M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M
M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`'-T<FYC;7``7U]E;G9I<F]N
M`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN
M<V\N-2XT,`!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T9"YS;RXQ
M`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]0
M05)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P
M87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S960`7U]D
M871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT97(D`'-H
M85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?<W1A<G0`
M<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L
M:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,C<````````"
M``$``P`#``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#``,``P`#``$`
M`P`!``$`!``#``$``P`#``$``P`!``,``P`!``,``0`!``,``0`#``,``P`!
M``,``P`#``$``P`$``,``0`#``,``P`!``,``P`!``,``0`!``4``P`#``,`
M`P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``,`"0,``!````!`````M)&6!@``!0"<!```
M$````+.1E@8```0`IP0``!````"'D98&```#`+($`````````0`!`!,#```0
M`````````(>1E@8```(`L@0```````"8JP````````,`````````+B``````
M``"@JP````````,`````````[B````````"HJP````````,`````````L"``
M``````#XKP````````,`````````8!X`````````L`````````,`````````
M`+`````````8L`````````,`````````$%(````````@L`````````,`````
M````>%0````````HL`````````,`````````@%0````````PL`````````,`
M````````B%0````````XL`````````,`````````D%0```````!(L```````
M``,`````````F%0```````"@KP````````(````"``````````````"HKP``
M``````(````,``````````````"PKP````````(````.``````````````"X
MKP````````(````8``````````````#`KP````````(````;````````````
M``#(KP````````L````A``````````````#0KP````````(````C````````
M``````#8KP````````(````F``````````````#@KP````````(````R````
M``````````#HKP````````(````V``````````````#PKP````````(````^
M``````````````#0K0````````4````#``````````````#8K0````````4`
M```$``````````````#@K0````````4````%``````````````#HK0``````
M``4````&``````````````#PK0````````4````'``````````````#XK0``
M``````4````(````````````````K@````````4````)```````````````(
MK@````````4````*```````````````0K@````````4````+````````````
M```8K@````````4````-```````````````@K@````````4````/````````
M```````HK@````````4````0```````````````PK@````````4````1````
M```````````XK@````````4````2``````````````!`K@````````4````3
M``````````````!(K@````````4````4``````````````!0K@````````4`
M```5``````````````!8K@````````4````6``````````````!@K@``````
M``4````7``````````````!HK@````````4````9``````````````!PK@``
M``````4````:``````````````!XK@````````4````<``````````````"`
MK@````````4````=``````````````"(K@````````4````>````````````
M``"0K@````````4````?``````````````"8K@````````4````B````````
M``````"@K@````````4````D``````````````"HK@````````4````E````
M``````````"PK@````````4````G``````````````"XK@````````4````H
M``````````````#`K@````````4````I``````````````#(K@````````4`
M```J``````````````#0K@````````4````K``````````````#8K@``````
M``4````L``````````````#@K@````````4````M``````````````#HK@``
M``````4````N``````````````#PK@````````4````O``````````````#X
MK@````````4````P````````````````KP````````4````Q````````````
M```(KP````````4````S```````````````0KP````````4````T````````
M```````8KP````````4````U```````````````@KP````````4````W````
M```````````HKP````````4````X```````````````PKP````````4````Y
M```````````````XKP````````4````Z``````````````!`KP````````4`
M```[``````````````!(KP````````4````\``````````````!0KP``````
M``4````]``````````````!8KP````````4````_``````````````!@KP``
M``````4```!```````````````!HKP````````4```!!``````````````!P
MKP````````4```!"``````````````!XKP````````4```!#````````````
M``"`KP````````4```!$``````````````"(KP````````4```!%````````
M``````"0KP````````4```!&`````````````````````````)>3```S`\-!
M`[X#,1,#0_V3@@,Q$U,3`(.R@@!G``X`%YX```,^#C!G`PX`$P```!>>```#
M/HXO9P,.`!,````7G@```SX.+V<##@`3````%YX```,^CBYG`PX`$P```!>>
M```#/@XN9P,.`!,````7G@```SZ.+6<##@`3````%YX```,^#BUG`PX`$P``
M`!>>```#/HXL9P,.`!,````7G@```SX.+&<##@`3````%YX```,^CBMG`PX`
M$P```!>>```#/@XK9P,.`!,````7G@```SZ.*F<##@`3````%YX```,^#BIG
M`PX`$P```!>>```#/HXI9P,.`!,````7G@```SX.*6<##@`3````%YX```,^
MCBAG`PX`$P```!>>```#/@XH9P,.`!,````7G@```SZ.)V<##@`3````%YX`
M``,^#B=G`PX`$P```!>>```#/HXF9P,.`!,````7G@```SX.)F<##@`3````
M%YX```,^CB5G`PX`$P```!>>```#/@XE9P,.`!,````7G@```SZ.)&<##@`3
M````%YX```,^#B1G`PX`$P```!>>```#/HXC9P,.`!,````7G@```SX.(V<#
M#@`3````%YX```,^CB)G`PX`$P```!>>```#/@XB9P,.`!,````7G@```SZ.
M(6<##@`3````%YX```,^#B%G`PX`$P```!>>```#/HX@9P,.`!,````7G@``
M`SX.(&<##@`3````%YX```,^CA]G`PX`$P```!>>```#/@X?9P,.`!,````7
MG@```SZ.'F<##@`3````%YX```,^#AYG`PX`$P```!>>```#/HX=9P,.`!,`
M```7G@```SX.'6<##@`3````%YX```,^CAQG`PX`$P```!>>```#/@X<9P,.
M`!,````7G@```SZ.&V<##@`3````%YX```,^#AMG`PX`$P```!>>```#/HX:
M9P,.`!,````7G@```SX.&F<##@`3````%YX```,^CAEG`PX`$P```!>>```#
M/@X99P,.`!,````7G@```SZ.&&<##@`3````%YX```,^#AAG`PX`$P```!>>
M```#/HX79P,.`!,````7G@```SX.%V<##@`3````%YX```,^CA9G`PX`$P``
M`!>>```#/@X69P,.`!,````7G@```SZ.%6<##@`3````%YX```,^#A5G`PX`
M$P```!>>```#/HX49P,.`!,````7G@```SX.%&<##@`3````'7&&[*+HRN"`
M$*;D3OQ2^*J'%YD```,YZ1(C.+3Z(S3$^I,%!/L3!H3Z$P7$^R,N]/J#-PD`
M(S3T_(%'[_!?]A>6```#-H80LH47E0```S7E$N\P0!Z7EP``@[>G$X/'!P!C
MA`<.EY<``(.W)Q"7E```DX2D&)*7F&.#*<3[@T>G2QN%20`.!9/G-P`C#?=*
M[_`?[(,U!/L7E@```S8&%8,GQ/L#N`4`JH87-P``$P=G5A<U```3!655F.Z4
MY".P!@&(YI#J!4>-*6-9]PRA!1N%-P`11Y!ADQ<W`+:7!2>0XZ$%XQFG_@X'
MB&PVER,P!P!.A@%'EP4``).%Q6CO\#^[-<F(;!,*1/SO\'_:JHG2A1<U```3
M!>4B[P!`&"7!B&SO\/^T[_"_RP,WA/R#-PD`N8\!1Z7KYF!&9*9D!FE">DZ%
MXGDE88*`[_!_QI>4``"3A*0*B.PAQ>_P?\^7EP``@[>G`(5F,X='`!AC-I<C
M"P>2";>(;._PG[MAMXAH`<7O$&!V:;_2A1<U```3!>43[P#`$(CH0=7EMQ%'
MJ;<%1>_P_[?O\+_C``#O`"`"JH<7E0```S5E_H)E,``3<0'_@48!1PJ([_"?
MW@*0EY$``).!(7V"@`$`01$BX`;D``@7E0``$P7E`)>7``"3AV<`8XNG`)>7
M``"#MR?VB<<"9*)@00&"AZ)@`F1!`8*`%Y4``!,%!?Z7E0``DX6%_8F-01&3
MUS5`_9$BX`;D``B^E86%D<F7EP``@[>G\HG'`F2B8$$!@H>B8`)D00&"@)>7
M``"#QP?ZE>M!$2+@!N0`")>7``"#MV?RD<<7E0```S5%\X*7[_!?]J)@`F2%
M1Q>7```C"/?V00&"@(*`01$BX`;D``@"9*)@00&5OUUQHN"&Y";\7N2`")>7
M``"#MV?J@[L'`&.$"PA.]%+P5NR#1P4`*HJNBJJ)$P?0`[7'8X;G`(/'&0"%
M"?W[NXE)08.T"P"YS$KX6NA>B1,+T`-.AM*%)H7O\+^9LX<T`0GE@\<'`&."
M9P.#-(D`(0GM\$)YHGD">N)J0FNF8`9DHFLFA>)T86&"@#,)>4$363E`A0DC
MH"H!SI3AOX%)5;>!1.F_HGD">N)JR;]Q<2+Q)NU*Z0`9!O47F0```SFIWI,%
MA/6#-PD`(SST_(%'JH3O\#^Y%>&#)X3VO6819_6/8X7G`"EG8YKG`":%B47O
M\%^8$S45`!&@`44#-X3]@S<)`+F/`4>9YZIP"G3J9$II36&"@._P_\)5<:+A
M3O6&Y8`)EYD``(.Y"=B#MPD`(SST^H%'&<4F_8-'!0"JA)GOZG0#-X3[@[<)
M`+F/`4=CD0<.KF`.9*IY:6&"@$KY[_!?O"J)8PP%#%+Q2H7O\'^.6<V#1C4!
M$PHU`9N&)OT;A@8`F>(#1AH`;=(#1S4!&P<G_9L&!P`!ZX-'&@";AR?]FX8'
M`+W/\=(FA5;M[_!_B*J*4H7O\/^'NXJJ`(DJ5H7O\#^(TH=6AB:'ES8``).&
M!M^)12J*[_#?L),%A/-2A>_P/Y3]5V,)]0"#)X3TO6819_6/8XKG`E*%[_"?
MCE*%[_`_GDJ%ZFKO\+^$/?%*A>_P/Y(FA>_PWXOJ=$IY"GH-MX-&*@!!MU*%
M[_#_[L&_)OU*^5+Q5NWO\+^PZG1*>0FW67&B\*;LRNC.Y(;TTN!6_%[T8O"`
M&)>9``"#N:G$`\<%`(.W"0`C//3X@4>3!]`#KH0JB6,4]P"3A!4`)H7O\"_[
MJHJ3!43Y2H7O\%_7*HIIS>_P[_EC>54+@RM$^1><```#/"S!C@L#1PD`RH>3
M!M`#8P('%&,&UP`#QQ<`A0=]^[N')T$#.@P`$X4J`#Z57IKO\._V(S"J`"G%
M@S<,``-'"0`3!1D`WI>48Q,&T`,C@.8``>N%J`-'!0`%!:.`YP`UP[:'A0;C
M&,?^$P?0`R.`YP"%!P/'!`"%!(4'HX_G_G7[`S>$^8.W"0"YCP%'X>NF<`9T
MYF1&::9I!FKB>J)[`GQE88*`@\<$`(4$!0JC#_K^X=N#QP0`A00%"J,/^O[]
M\\&WMH=5MUKX9NQJZ!><```#/`RT`ST,`(,W#0"MS^J'`4J89Z$'TH8%*F7_
MC283FS8`EY<``(.G)[P7EP``$P>GNXWOA4=:A1S#[_`OZ:J,.<F3&SH`VH;J
MA5Z&[_`/_",PG`&;!QH`C@>^G".P#`!">^)L0FTC*D3YZ;7:A6J%[_#?B2,P
MK`"JC!'-DQLZ`-&_@4?YM4%+`4IAOUKX9NQJZ._POY-">^)L0FT1OUUQHN`F
M_$KX3O12\%;L@`B&Y/UR_7>3AX?[%I&%9)>:``"#N@JGJHDNBA.&]/^S!?0`
M%S4``!,%Q;>#MPH`(SST^H%'[_"OZAL)!0!C6R`!LP240)L'^?^^E`/'A/L=
M[XWOEY<``(.W1Z52ALZ%DI>(8^_PS^(#-X3[@[<*`+F/`4>IYX5B%I&F8`9D
MXG1">:)Y`GKB:F%A@H`^B?UWDX>'^[,$]``FA4J&DP7P`N_P#_=%V9>7``"#
MMR>@RH8FAI*7B&/.A>_PC^]UM^_P/X8!$2;DEY0``(.T))XBZ`;L`!"SAT0`
MB&.7=@``DX;FP!>6```#-N:<ES4``).%9:SO\._]DI1"9(A@XF"B9!<W```3
M!P?DNH:!1Q<6```3!J;UES4``).%Q:L%86_P+^:7EP``@[=GF$$1(N`&Y``(
MDI<"9*)@B&.7=@``DX;FNA>6```#-N:6ES4``).%9:9!`6_PS_<=<8;LHNBF
MY(`0RN!._%+X5O3Y<A>:```#.DJ1%I&#-PH`(SST^H%'[_`/W/EWDX>'^K,$
M]``%9BJ'!08FA9<W``"3AR>EES8``).&)J6)1>_PC_']=Y.'!_LS"?0`)H7*
MA05F[_!/TIL$!0"!26/!!`*;BA0`5H7O\`_%JHD)R2:&UH;*A<Z4[_`/\R.`
M!``#-X3[@S<*`+F/`4>)[XEB%I'F8$Z%1F2F9`9IXGE">J)Z)6&"@._P+_%!
M$2+@!N0`"`)DHF!!`26_47&B\:;MRNG.Y5[U@!F&]=+A5OU:^6+Q9NW]<OUW
MDX='\1:1EYL``(.[JX.JB:Z$%S4``!,%99NS!?0`@[<+`",\]/B!1^_P?Y<J
MB9,%\`).A>_PS]4AP1<U```3!>69SH7O\-^Y3H4#-X3Y@[<+`+F/`4=CG@<2
MA6(6D:YP#G3N9$YIKFD.:NIZ2GNJ>PI\ZFQM88*`)H7O\&_4ES4``).%I9;O
M\*^OJH1=U?UW$X>'^9.'A_$%:[,*]`"3!P3Z,XQG08/'!``S"N0`Q<-C!PD`
MIH5*A>_PC\4ES2:%[_`/L9,']?^FEZJ,DP;P`F/H]``QJ".`!P#]%V.&]``#
MQP<`XPG7_B:%[_!OKJJ,3H7O\.^M9I4%!>-P9?6)12:'3HB7-P``DX?'CI<V
M``"3AL:.!692A>_PC];6A5*%[_`/N@'I@R>,^+UF(6?UCV.!YP27-0``DX5%
MBP%%[_`OI*J$XPL%[H/'!`"U\V,,"0"#1PD`FX<G_1N'!P"9XP-'&0!AVX5,
MES0``).$A(5!MX5%4H7O\*^I3?W2A1<U```3!:6%[_"_I5*%[_!/PVV][_#O
MU`$1(N@FY`;L`!"3!?`"JH3O\*_$&<&3!!4`0F3B8":%HF0%86_P;\`Y<2+X
M3NP&_";T2O"``/UREXD``(.Y*6<6D8.W"0`C-/3\@4=9R8-'!0`JB=G'[_!/
MGA,&%0"%9ZJ$8^C'"OUWDX>'_#,']`#*A3J%[_!OKI.']/^JEY,&\`)C:/4`
M$:@C@`<`_1=CAJ<``\<'`.,)U_[]=Y.'A_RS!/0`)H63!?`"[_`/NQ7)8^ZD
M!/UWDX>'_#,%]`#O\,^V`S>$_(.W"0"YCP%'H>>%8A:1XG!"=*)T`GGB:2%A
M@H`#-X3\@[<)`+F/`4>%YX5B%I'B<$)THG0">>)I%R4``!,%Q7(A86_P+[(C
M``4`5;<!17VW[_!/PSEQ(O@F]$KP3NR```;\%XD```,Y*5B3!$3\@S<)`",T
M]/R!1Y>)``"#N<E7IH47)0``$P4E<N_PC^L5Q0,G1/R#MPD`#@>ZEYAGF.-E
MTYAKH0>8XVW_IH47)0``$P6%;^_P[^AA_9>)``"#N:E3IH47)0``$P4%;^_P
M;^<5Q0,G1/R#MPD`#@>ZEYAGF.-ETYAKH0>8XVW_IH47)0``$P5E;._PS^1A
M_9>)``"#N8E/IH47)0``$P5E:^_P3^,5Q0,G1/R#MPD`#@>ZEYAGF.-ETYAK
MH0>8XVW_IH47)0``$P7%:._PK^!A_9>)``"#N6E+IH47)0``$P5%:._P+]\5
MQ0,G1/R#MPD`#@>ZEYAGF.-ETYAKH0>8XVW_IH47)0``$P6E9>_PC]QA_9>)
M``"#N4E'IH47)0``$P6E9._P#]L5Q0,G1/R#MPD`#@>ZEYAGF.-ETYAKH0>8
MXVW_IH47)0``$P4%8N_P;]AA_9>)``"#N2E#IH47)0``$P6%8>_P[]85Q0,G
M1/R#MPD`#@>ZEYAGF.-ETYAKH0>8XVW_IH47)0``$P7E7N_P3]1A_9>)``"#
MN0D_IH47)0``$P7E5>_PS](5Q0,G1/R#MPD`#@>ZEYAGF.-ETYAKH0>8XVW_
MIH47)0``$P5%4^_P+]!A_9>)``"#N>DZIH47)0``$P5%6N_PK\X5Q0,G1/R#
MMPD`#@>ZEYAGF.-ETYAKH0>8XVW_IH47)0``$P6E5^_P#\QA_9>)``"#N<DV
MIH47)0``$P4E5^_PC\H5Q0,G1/R#MPD`#@>ZEYAGF.-ETYAKH0>8XVW_IH47
M)0``$P6%5._P[\=A_9>)``"#N:DRIH47)0``$P4%5._P;\85Q0,G1/R#MPD`
M#@>ZEYAGF.-ETYAKH0>8XVW_IH47)0``$P5E4>_PS\-A_9>)``"#N8DNIH47
M)0``$P5E1N_P3\(5Q0,G1/R#MPD`#@>ZEYAGF.-ETYAKH0>8XVW_IH47)0``
M$P7%0^_PK[]A_::%%R4``!,%14WO\*^^JH49Q1<E```3!45*[_#/X::%%R4`
M`!,%Y4SO\,^\JH49Q1<E```3!65-[_#OWZ:%%R4``!,%A4WO\.^ZJH45S1<E
M```3!04][_`/W@,WA/R#-PD`N8\!1ZGC0G3B<*)T`GGB:9<E``"3A<5,%R4`
M`!,%Q4`A86_P+]NFA1<E```3!<5)[_`OMJJ%:=$7)0``$P7%0._P3]E5O^_P
M[XAY<2+P)NP`&`;TEX0``(.T!!Z3!43]%R4``!,%13Z<8",\]/R!1^_P+[(%
MQ8-'!0`!18G'DX<'_3,U\``#-X3]G&"YCP%'@>NB<`)TXF1%88*``47EM^_P
M3X,=<2+H!NP`$!>#```#,X,<*HX#-0,`$P.$``SD$.@4['*&&/`7C@```S[.
M%AST(S@$`R,\%`.:AHE%@S<.`",T]/Z!1R,P9/[OX)_6$P7P#^_@'](=<:+H
M3OQ2^%;TANRFY,K@6O!>[(`0P7*7B@``@[I*$A:1"4:#MPH`(S3T^H%'@44J
MBN_@O^*3"?7_$]?Y0T&3LX?I`,(7P9.9C[.)^4!CS`D(P7>3AP?Z,PGT`'U;
MG4L!1LZ%4H7OX'_?8P9E"4%F(0;*A5*%[^!_ZP$E8P=E!V/_JP1A%;,$J0!C
M]B0!@:C]%&/F)`4A1I>%``"3A<40)H7OX+_8;?7!=Y.'!_JBES.%]$!.E0,W
MA/J#MPH`N8\!1Z'CP6(6D>9@1F2F9`9IXGE">J)Z`GOB:R5A@H#!=[Z9XY_Y
M]GU5^;<7)0``$P4E,>_PO^L7)0``$P5E+^_P_^KOX+_M01$&Y"+@``COX/^Z
M[^"_Y1'!"&&B8`)D00&"@#EQ(OA*\$[L@``&_)>)``"#N>D`*HF3!43\%R4`
M`!,%!2V#MPD`(S3T_(%'[_#/E!G%)O2#1P4`JH2-YZ)T`S>$_(.W"0"YCP%'
MRH47)0``$P7E*:WK0G3B<`)YXFDA86_PK[5*A5+H[^`_M"J*)H7OX+^S*IH)
M"E*%[^`?M":(2H>7)P``DX<'%%*&ER8``).&9A2)1:J$[^`_W`,WA/R#MPD`
MN8\!1YWC0G1":N)P`GGB:::%HG07)0``$P4E(R%A;_"/KR;T4NCOX!_?[^#?
MWB5QEX<``).'Y_HBZTKC`!/._M+Z!N\FYP.XAP,#OP<!@[Z'`0.^!P(#LX<"
M@[@'`Q,)Q.<7B@```SI*\:J)%R8``!,&)A^7)@``DX8F"!<G```3!Z<>ER<`
M`).'IQXC/`3MRH47)0``$P7%!@,X"@`C/`3Y`4@C.`3H(S0$ZB,XY.LC/-3K
M(S#$[2,T9.PC.!3M(S#$Z",TU.@C/.3H(S#TZN_P3X`1Q8-'!0"JA&.:!R+6
M]MKRWN[BZN_@_Z#OX+_+8P@%&`,[!0!C!`L86H7OX)^@DQ05`(4$)H7OX-^@
M`T<+`*J+)HRJB@7/ER8``).&1A8FAHE%7H7OX/_(!0OBAF-SG`"FAK.'ED")
M!V/SUP"VAP-'"P#Y%)6,OI2)"W'W$PL$ZQ<E```3!24)*:`#-8L`(0L-P<J%
M[^#?]JJ$9=F#1P4`[=?O\*^`==$FA>_@G[>JA!7A$PL$Z(,T"P")S(/'!`!C
MA`<.)H7OX'_^>>6#-(L`(0OM]":%[^#?E2J+5H7OX%^5.PNK`!L+2T!:A>_@
M?Y67)P``DX<G]M:()H=:AA<H```3"$@+ER8``).&1@N)1:J+[^`?O5Z%DP4`
M'._@?Z[]5V,8]0#OX-^3'$%%1V.7YPZ3!03N7H7OX+^RJH0!Z8,G!.^]9A%G
M]8]CB.<*EX<``(.W1]F#M@D`B&->AQ<F```3!L8*B47OX+^U@4H#-X3Y@S<*
M`+F/`4=CG0<N^F!:9!9[]FM6;+ID&FGV>59Z5H6V>AUA@H`FA>_@GZBJA"$+
MXPH%\#VW@40MMY,$A.F(8!G)RH7OX+_D`<6#1P4`E>.(9*$$??4U1>_@GX<U
M3*J+JHKBA!<K```3"\OZ$P<P!96U[^#_HRJ+H01QT>_@7X23%!4`A00UO8,J
MA._OX%^"XY:J](,G!._FYA,'`!R3]_<?8XCG!+9L%;\7AP```S=GS(.V"0`(
M8Q<F```3!@;Z7H>)1>_@WZ@-O^_PW\0#-X3Y@S<*`+F/`4=CEP<B6F3Z8!II
M]GE6>B:%NF0=86_@/YQ:A>_@S_W*A:J*%R4``!,%1?_OX+_8JH5C"P40`[4)
M`._P#[RJC&,$!1!FA>_@+_H;#`4`C4=CV(<#$P7,_V:5ER4``).%9?SOX'^,
M">V11V,$_!B;![S_YI<#QP<`DP?P`F,+]Q;*A1<E```3!67>[^#?TF'!@T<%
M`,W/$P<``V.*YPJ7)0``DX4EYA<E```3!27<[^"_]._@?X8JB%Z'6H96A9<H
M``"3B*@%ER<``).')]27)@``DX8F^(E%[^`?G'U9Q4D7+```$PR,`Q6H[^#O
M\AQ!8YTW`^_@7X*%)"J(8N"FB%Z'6H96A9<G``"3AR?0ER8``).&)O6)1>_@
M'YB3!0`<5H7OX'^)XP(E_5Z%[^#?AM:%%R4``!,%Y<KOX/_K5H7O\/^OMFSY
MNX.\"0#EO6:%@47OX'^;*HDYT>_P/YRJB>-/!?*3!67_`49*A>_@WX`3#`3V
MXH5*A1E&[^#_C)E'8Q_U"`,G!/:W1T%#DX<',.,7]_`#5TP`D6>3AX=4XQ#W
M\).%Z?P!1DJ%[^#O_),$A/9*A::%$P:``N_@_XB3!X`"8Q[U!":(6H:7*```
MDXCH])<G``"3AV?#7H>7)@``DX9&YHE%5H4C"`3X[^#?BBV_@[F)`..%">A.
MA>_@S]Z-1^/_I^9Q%4Z5ER4``).%Y>'OX&_QXQ4%YLZ,E;47)0``$P4EX>_P
M/XKFYN_@WXS6]MKRWN[BZN;F[^#_BUUQ)OR7A```@[3DHZ+@3O12\(;D2OA6
M[(`(LX=$``.Y!P`3"D3[EXD``(.Y29^#1PD+TH47)0``$P5EO0.W"0`C/.3Z
M`4>C"/D*[^#_LAG%`T<%`),'$`-C`?<4[_#OPK.'1``#N0<`2H6-1@5&ER4`
M`).%Q=SOX$_:*HD%Q1QI,X=$``ACC&,7)@``$P:FV^_@K]F#-PD!C&/<11.7
MEP)C20<0LX=$`(ACC48%1I<E``"3A<79[^!/UBJ)EXH``).*:J$5P=*%%R4`
M`!,%I:[OX)^J@S<)`2J&C&-AQ;.'1`"(8^_@;]2SAT0``[D'``5&ER4``).%
M!=9*A>_@[\>JA1<F```3!H;62H7OX._1DI2<8-*%%R4``!,%Q:BCB`<*[^!_
MI2.XJ@"JA"G)DP4`'":%[^!OY!L'%0"%1V/PYP+%1V,-]0"#MXH`JH8FAHQC
M%R4``!,%A=3OX`_I`S>$^X.W"0"YCP%'L>NF8`9DXG1">:)Y`GKB:F%A@H`#
MM8H`[_`?E2.XJ@"JA$WQ%R4``!,%1<[OX$_E@T<5`..%!^QMO8.WB@`NA8QC
M[^`?WB6_LX=$`(AC[^`OX.6U[^#/[SEQ(O@F]$KP@``&_)>$``"#M,2$*HF3
M!43\%R4``!,%Y:2<8",T]/R!1^_@WY@)S8-'!0"1RQ,'``-CA^<`8P4)`(-'
M"0")[P,WA/R<8+F/`4>Y[^)P0G2B=`)Y(6&"@$J%3NSO\"^7DP7P`JJ)[^"O
MV1G!DPD5`$Z%[^#OU1%&ER4``).%A:[OX`^R&<'B:66_`S>$_)Q@N8\!1YGK
M0G3B:>)PHG1*A0)Y(6%OX#^B3NSOX&_D$P$!U",X@2J`!2,\$2HC-)$J(S`A
M*R,\,2F7<P``@[.#>),&A-3!;I,(A0.3#X4'@[<#`",T]/R!1S:(DXX.\#</
M_P`#M@@`H0A!")-5!@(3%X8!$Y.%`9,2A@"35X8"`A<37H8`DU2&`P&3`A.S
M\N(!L_?7`1-3`P(S9U<`,W[>`:(%Q8\S9\<!&U:&`;/UY0&SYV<`48_-CR,X
MZ/XC//C^XY'X^P,_!-N#/H3;`S<$W`,^A-4#,P36@SB$U@,X!->#-837@S\$
MV).$!B`1H+*/L&*<8KJ"H0:QC[/'YP&SQ\<!$Y<7`/V#78\"%P&3N/X:CG:/
M1H.6CL*(+HC^A>.8U/P080QI@SB%``,XA0&#-H34`S,%`I-7M@$3%U8`-XZ"
M6A,.GIE=C_*6L\<%`1/?*``"%Y.>Z`&:EK/N[@$!D[/W%P$VE[/'!P&#-@35
M$Y\.`A-?#P(^EP(7L\?E`0&3\8_REI-2MP&3'U<`K8_"EK/O7P"VEY-2)@#^
MEY,6Y@&#/X35L^96`+/.W@""%X&3L_[N`/*?D]2W`:Z?DY)7`+/.[@&SXI(`
M_IZ6GI,?YP&#,@36"8,SY^\`@AZ3GP8"N8Z3W@X"D]\/`O*2_8X6GY/4O@&3
MDEX`L\;V`?J6,^^2`/J6DY+G`0,_A-:)@[/G\@""%I,2!P(]CX&2D]("`G*?
M,W?7`7Z?D]2V`9.?5@`S1U<`>I<S[Y\`>I>#/P37$Y_N`9/>+@`S;]\!$YD'
M`@(7L\?G`0&3$UD)`K..SP'UCY:>DQ]7`)-2MP&SQR<!]I>S[E\`]I>#,H37
MD]XF`).?Y@&S[]\!LT;_`9,4#P*"%X&3@9"SCL(!^8[*GA.?5P"3TK<!I8[V
MEK-N7P#VEH,R!-B37B<`$Q_G`3-OWP$SQ^\!$YD/`H(6@9(360D"LX["`7V/
MIIZ3GU8`D]*V`3-')P%VE[/N7P!VEX,_A-B3WB<`DY+G`;/BT@&S1U\`DQ0/
M`@(7`9.!D+..SP'UC\J>$Q]7`)-?MP&EC_:7LV[_`?:7`S\$V9/>)@"3G^8!
ML^_?`;/&\@$3F0("@A>!DQ-9"0*S#L\!^8ZFGA.?5P"3TK<!L\8F`?:6LVY?
M`/:6@S*$V9->)P`3'^<!,V_?`3/'[P&3E`\"@A:!DH&0LX["`7V/RIZ3GU8`
MD]*V`26/=I>S[E\`=I>#,@3:D]XG`).?YP&S[]\!LT?_`1,9#P("%P&3$UD)
M`K..P@'UCZ:>$Q]7`)-2MP&SQR<!]I>S;E\`]I>#,H3:D]XF`!.?Y@$S;]\!
ML\;O`9.4#P*"%X&3@9"SCL(!^8[*GI.?5P"3TK<!I8[VEK/N7P#VEH,R!-N3
M7B<`DQ_G`;/OWP$S1_\!$QD/`H(6@9(360D"LX["`7V/IIX3GU8`D]*V`3-'
M)P%VE[-N7P!VEX,RA-N3WB<`$Y_G`3-OWP&SQ^\!DY0/`@(7`9.!D+..P@'U
MC\J>DQ]7`)-2MP&EC_:7L^Y?`/:7@S($W)/>)@"3G^8!L^_?`;-&_P&3&0\"
M@A>!DY/9"0*SCL(!^8ZFGA.?5P"3TK<!L\8V`?:6LVY?`(,TA-SVEI,2YP&3
M7B<`L^+2`3/'7P`3GP8"$YD/`A-?#P(360D"LX;$`7V/SI:3'E\`DU^_`3-'
M)P$VE[/F_@&#-`3=-I>3WR<`DY;G`;/F]@&SQ](`DQX'`I.?`@*3W@X",X?$
M`9/?#P*S]^<!2I>3DEX`D]2^`;/']P&ZES/GD@"ZEX,TA-T3%^\!@A<37R\`
M@9,S9^<!$]FW`9.2!@(3GU<`N8[RE)/2`@(S;R\!L_;6`::?L\96``(?$U\/
M`OZ6^I8#.03>DY_N`1.?!@*3WBX`$U\/`K/NWP&3%%\`<IF3'P<"$UZ_`3-'
MUP&3WP\",^[$`7V/RI(S1_<!`AX37@X"%I>3DN<!B8-RE[/B\@"SQUX``SF$
MWI,4!P*!D+6/M_;9;I.&%KJ3V;0!$YY4`#:9,VX^`8(7RI^!DP(>_I<37@X"
M/IZ3'^\!$U\O`+/O[P&#-P3?$QD.`A-9"0(SS_(!DUFY`3-/[P""'A,760"3
MW@X",V<W`;:7`A\37P\"]I<"%_J7`9,^EY.>Y`&)@+/NG@"#-X3?DQD'`I/9
M"0(SS]\!D]2Y`3-/SP&"$A.>60"3T@(",VZ>`+:7`A\37P\"EI<"'OJ7$UX.
M`CZ>$Q_I`1-9*0`S;R\!@S<$X),2#@*3T@("L\3N`1/9L@&YC((?$Y=2`)/?
M#P(S9R<!MI>"%(&0_I<"%Z:7`9,^EY.?Z0&3V2D`L^\_`8,WA."3%`<"@9`S
M2?\!D]FT`3-)R0&"'A.>5`"3W@X",VX^`;:7`AD360D"]I<"'LJ7$UX.`CZ>
MDY[B`9/2(@"S[EX`@S<$X1,9#@(360D"L\+?`9-9N0&SPN(``A\3%UD`$U\/
M`C-G-P&VEX(2D]("`OJ7`A>6EP&3/I<3G^0!B8`S;Y\`@S>$X9,2!P*3T@("
ML\3N`9/9L@&SQ,0!@A\3GE(`D]\/`C-N/@&VEX(4@9#^EP(>II<37@X"/IZ3
M'^D!$UDI`(,W!.*S[R\!DQ0.`H&0,TG_`9/9M`$S2>D`@AX3EU0`D]X.`C-G
M-P&VEP(9$UD)`O:7`A?*EP&3/I>3GN(!D](B`+/N7@"#-X3B$QD'`A-9"0*S
MPM\!DUFY`;/"P@$"'Q,>60`37P\",VX^`;:7@A*3T@("^I<"'I:7$UX.`CZ>
M$Y_D`8F`,V^?`(,W!..3$@X"D]("`K/$[@&3V;(!N8R"'Q.74@"3WP\",V<W
M`;:7@A2!D/Z7`A>FEP&3/I>3'^D!$UDI`+/O+P&#-X3CDQ0'`H&0,TG_`9/9
MM`$S2<D!@AX3GE0`D]X.`C-N/@&VEP(9$UD)`O:7`A[*EQ->#@(^GI.>X@&3
MTB(`L^Y>`(,W!.03&0X"$UD)`K/"WP&36;D!L\+B``(?$Q=9`!-?#P(S9S<!
MMI>"$I/2`@+ZEP(7EI<!DSZ7$Y_D`8F`,V^?`(,WA.23$@<"D]("`K/$[@&3
MV;(!L\3$`8(?$YY2`)/?#P(S;CX!MI>"%(&0_I<"'J:7$UX.`CZ>DQ_I`1-9
M*0"S[R\!@S<$Y9,4#@*!D#-)_P&3V;0!,TGI`((>$Y=4`)/>#@(S9S<!MI<"
M&1-9"0+VEP(7RI<!DSZ7DY[B`9/2(@"S[EX`@S>$Y1,9!P(360D"L\+?`9-9
MN0&SPL(!`A\3'ED`$U\/`C-N/@&VEX(2D]("`OJ7`AZ6EQ->#@(^GA.?Y`&)
M@#-OGP"#-P3FDQD.`I/9"0*SPNX!D]2Y`;/"X@""'Q.760"3WP\"18^VEX(2
MD]("`OZ7`A>6EP&3/I>3'^D!$UDI`+/O+P&#-X3FDQ0'`H&0LT+_`1/9M`&S
MPL(!@AX3GE0`D]X.`C-N+@&VEX(2D]("`O:7`AZ6EQ->#@*SCL<!DY+I`9/9
M*0"SXC(!@S<$YQ.9#@(360D",\Y?`)-9N0$S3NX``A\3%UD`$U\/`C-G-P&V
MEP(>$UX.`OJ7`A<!DQ.?Y`'REXF`,V^?`#..YP`#-X3GL\?B`;/'UP&3%`X"
M@A^!D)/?#P(VEX(7DYY4`)/9M`&!DWZ7/I>3'^D!L^<^`1-9*0"S[R\!/I>#
M-P3H,TG_`9,>!P(S3LD!@A*3W@X"D]("`K:7`AX37@X"EI>3EEX`D]*^`;/F
M5@`3E^0!\I>)@(,RA.A%C[:7M_;&(Y,4!P(3G@<"DY<F`).'Q\V!D+/F[P`3
M&0\"$UX.`C./\@`360D"L_*?`+/VU@%*G[/F5@`36;X!DQ)>`/J6,^\B`?J6
M`SD$Z1.?[@&3WBX`,V_?`9.2#P(S9^<!DY\&`I/?#P*S=I\`LP[Y`)/2`@(S
M=\<!EIX3V;\!DY)?`%6/=I>3%NX!L^XB`1->+@"SYL8!=I>#/H3IDY(&`I/2
M`@(S;M\``A<!DS-Y7P"^GC-^_@&FGC-N+@&3%%<`$UFW`7:>L^XD`7:>`SD$
MZI.>[P&3WR\`L^[^`9,4#@*SYM8!`A^!D+/_7@`S#OD`$U\/`OF.>IZSYO8!
MD]FT`9.?5``3&><!$U\G`#.'Q@&S9ND!,^X_`0,_A.IREY.?!@*3WP\",^[>
M``(7`9,S^?X!/I\S?IX`%I\S;BX!DQ)7`!-9MP%ZGC/O(@%ZG@,Y!.L3G^0!
MB8`S;Y\`DQ(.`K/FY@&"'I/2`@*S=/\!,P[Y`)/>#@+YCG:>Q8Z3V;(!DY12
M`!,9YP&37B<`,X?&`;-FV0$S[C0!@SZ$ZW*7DY0&`H&0,V[?``(7`9,S>9\`
MOIXS?EX`_IXS;BX!DQ]7`!-9MP%VGK/N+P%VG@,Y!.R3GN(!D](B`+/N7@"3
M'PX"L^;6`0(?D]\/`K/RG@`S#OD`$U\/`OF.>IZSYE8`D]F_`9.27P`3&><!
M$U\G`#.'Q@&S9ND!,^XR`0,_A.QREY.2!@*3T@(",^[>``(7`9,S^5X`/I\S
M?OX!)I\S;BX!DQ17`!-9MP%ZGC/O)`%ZG@,Y!.T3G^\!D]\O`#-O_P&3%`X"
ML^;F`8(>@9"S?U\`,P[Y`)/>#@+YCG:>L^;V`9/9M`&3GU0`$QGG`9->)P`S
MA\8!LV;9`3/N/P&#/H3M<I>3GP8"D]\/`C-NWP`"%P&3,WG_`;Z>,WZ>`):>
M,VXN`9,25P`36;<!=IZS[B(!=IX#.03NDY[D`8F`L^Z>`),2#@*SYM8!`A^3
MT@("L_3^`3,.^0`37P\"^8YZGL6.D]FR`9.44@`3&><!$U\G`#.'Q@$S[C0!
MLV;I`8,TA.YREQ.?!@(37P\",^[>``(7`9,S^>X!OI0S?EX`II\S;BX!DQ17
M`!-9MP%^GK/O)`%^G@,Y!.^3G^(!D](B`+/O7P"3%`X"L^;V`8(>@9"S\N\!
M,P[Y`)/>#@+YCG:>L^96`)/9M`&3DE0`$QGG`9->)P`SA\8!,^XR`;-FV0&#
M,H3O<I>3G@8"D]X.`C/NWP`"%P&3,_G?`;Z2,WZ>`!:?,VXN`9,25P`36;<!
M>IXS[R(!>IX#.03P$Y_D`8F`,V^?`),2#@*SYN8!@A^3T@("LW3?`3,.^0"3
MWP\"^8Y^GA/9L@&3GU(`Q8Z3%.<!"8-%C_*6@S2$\#/N+P'REI,?!P*3WP\"
M,V[O`((6@9(S>?\!OI0S?EX`IIXS;BX!DY16`!/9M@%VGK/N)`%VGH,T!/$3
MF>(!D](B`),>#@(S;ED`,V?'`0(?D]X.`K."]`!UC[-T_@$37P\"%I]%CY.2
M7@"3U+X!>I<S[Y(``SF$\7J7$Y_F`8F"LV;?``(7`9.3D@8"D]("`C-OW@"3
M6;<!/IF3%%<`RI^SY#0!,WE>`#-_WP$S;R\!@A2!D'Z?`SD$\B:?DQ\/`I/?
M#P*3E.X!D]XN`+/NU`$^F9.47P"3U[\!L^;6`=V,`AZS]^8`$UX.`I.6!`*S
M]%X`2I[%C_*7@9*^EI,4YP$)@]F,@SF$\A.9!@*WMY@R$UD)`C/'G@"*!Y.'
M9QTS1^<!$QY9`!-?N0$S;NX!`A<SC_D`%I\!DP(>>I<37@X".IX3G^\!$]<O
M`+-O[P"3$@X"`S\$\Y/2`@(SQ_0!D]FR`36/@AZ3EE(`/I^SYC8!D]X.`@(7
M^IX!DX(6=I>!DKJ6DQ[I`1-7*0"S[NX`$YD&`@,WA/,360D",\_?`9-9N0$S
M3\\!@A03'ED`@9`S;CX!/I<"'Q-?#P(FEP(>>I<37@X".IX3G^(!D](B`#-O
M7P"3%`X"`S<$](&0L\+N`9/9M`&SPM(`@A^3EE0`D]\/`K/F-@$^EX(2D]("
M`GZ7@A86EX&2NI:3'^D!$UDI`+/O+P&3D@8"`S>$])/2`@(S2?\!D]FR`3-)
MR0&"'A.>4@"3W@X",VX^`3Z7`AD360D"=I<"'DJ7$UX.`CJ>DY[D`8F`L^Z>
M`!,9#@(#-P3U$UD)`K/$WP&36;D!M8P"'Y,660`37P\"L^8V`3Z7@A2!D'J7
M@A8FEX&2NI83G^(!D](B`#-O7P"3E`8"`S>$]8&0L\+N`9/9M`&SPL(!@A\3
MGE0`D]\/`C-N/@$^EX(2D]("`GZ7`AX6EQ->#@(ZGI,?Z0$362D`L^\O`9,2
M#@(#-P3VD]("`C-)_P&3V;(!,TG9`((>DY92`)/>#@*SYC8!/I<"&1-9"0)V
MEX(62I>!DKJ6DY[D`8F`L^Z>`!.9!@(#-X3V$UD)`K/$WP&36;D!L\3$`0(?
M$QY9`!-?#P(S;CX!/I>"%(&0>I<"'B:7$UX.`CJ>$Y_B`9/2(@`S;U\`DQ0.
M`@,W!/>!D+/"[@&3V;0!L\+2`((?DY94`)/?#P*SYC8!/I>"$I/2`@)^EX(6
M%I>!DKJ6DQ_I`1-9*0"S[R\!DY(&`@,WA/>3T@(",TG_`9/9L@$S2<D!@AX3
MGE(`D]X.`C-N/@$^EP(9$UD)`G:7`AY*EQ->#@(ZGI.>Y`&)@+/NG@`3&0X"
M`S<$^!-9"0*SQ-\!DUFY`;6,`A^3%ED`$U\/`K/F-@$^EX(4@9!ZEX(6)I>!
MDKJ6$Y_B`9/2(@`S;U\`DY0&`@,WA/B!D+/"[@&3V;0!L\+"`8(?$YY4`)/?
M#P(S;CX!/I>"$I/2`@)^EP(>%I<37@X".IZ3'^D!$UDI`+/O+P&3$@X"`S<$
M^9/2`@(S2?\!D]FR`3-)V0""'I.64@"3W@X"L^8V`3Z7`AD360D"=I>"%DJ7
M@9*ZEI.>Y`&)@+/NG@`3F08"`S>$^1-9"0*SQ-\!DUFY`;/$Q`$"'Q,>60`3
M7P\",VX^`3Z7@A2!D'J7`AXFEQ->#@(ZGA.?X@&3TB(`,V]?`),4#@(#-P3Z
M@9"SPNX!D]FT`;/"T@""'Y.65`"3WP\"L^8V`3Z7@A*3T@("?I>"%A:7@9*Z
MEI,?Z0$362D`L^\O`9.9!@(#-X3ZD]D)`K-"_P$3V;D!L\+"`8(>$YY9`)/>
M#@(S;BX!/I>"$I/2`@)VEP(>%I<37@X"LP['`9.2Y`&)@+/BD@`3F0X"`S<$
M^Q-9"0(SSE\`DU2Y`3-.W@`"'Y,660`37P\"Q8X^EP(>$UX.`GJ7@A:!DA.?
MZ0%REY/9*0`S;S\!,P[7`(,VA/LSQ^(!,T?7`8(?D]\/`I,4#@*^E@(7@9`!
MD_Z6D]FT`9.?5`"ZEI,>Z0$#-P3\$UDI`+/O/P&S[BX!_I:S3]\!NI>"$H(6
M,\[/`8&2LI>3T@("`AX3U[8!$Y96`!->#@*6EUF.\I<3E^0!B8"RET6/+I<S
M!F\`QI;"GH(7@9,"%H(6DY4.`@(7@9(!DH&1`9,<X13E$/$,[8,VA/R#MP,`
MM8^!1ACID>^#,($K`S0!*X,T@2H#.0$J@SF!*1,!`2R"@._0;XQ!$2+@!N0`
M"!,%``COP'_;%T@```,X*$FW=EU,-W?I888&MR5%9S=6,A`&!Y.&YL^3A14P
M$P9F1Q,'!Q\4Z2,T!0(C.`4"(RP%!@SA(S0%`1#M&/&B8`)D00&"@%UQHN!*
M^$[T5NQ:Z(;D)OQ2\(`(&'63%S8`LHFZEQ!Y@A>!DS.WYP`JB9/6V0$H73J6
M,X?&`",T^0(C..D"+HN3"HD#->V3!_`#8]HW!1O::0!>Y)L+^O]BX!H*$YP+
M`A-<#`):FMJ$IH43!@`$5H7OP'_@DX0$!$J%[^"_FN.51/^["W!!FYMK`!H,
MFXD)_!,+"P2[B3L!8INB:P)LVH56A4Z&[\`_W2,L.0>F8`9DXG1">:)Y`GKB
M:D)K86&"@),'``2)G[Z$8\OY`AN*!`"3"HD#4H96E=J%[\#?V8,GB0<3!P`$
MI9\C+/D&XY#G_$J%NXF90%*;[^#?DJFWSH3QMUUQHN`F_$KX4O!6[%[DAN1.
M]%KH@`B#N84"@]:%`@/7!0.3USD`DXN%`Y/W]P,3VH8`DUJ'`)N6A@`;%X<`
M,X;[`*Z$,VK:`),%`/BSZNH``[L$`X4G(P"V`$(:PAH3!H`#*HD36@H#,X7[
M`)/:"@-C5O80$P<`!+L']T`11V/PYQ()1V/TYQ!CGP<.)H7OX%^)7H43!H`#
M@47OP+_BD]>)`1-7BP&3V0D!$UL+`2.95`<CFT0'HXAD!R.*]`:CBC0')H4C
MB.0&[^"_A9Q@)H7A@R,`^0"<8,&#HP#Y`)Q@H8,C`?D`G&"C`?D`G&3A@R,"
M^0"<9,&#HP+Y`)QDH8,C`_D`G&2C`_D`G&CA@R,$^0"<:,&#HP3Y`)QHH8,C
M!?D`G&BC!?D`G&SA@R,&^0"<;,&#HP;Y`)QLH8,C!_D`G&RC!_D`G'#A@R,(
M^0"<<,&#HPCY`)QPH8,C"?D`G'"C"?D`!F2F8.)T0GFB>0)ZXFI":Z)K86%O
MP-_('9Z!1>_`7]0IOR,`!0`)MR,`!0"C``4`^1<ZE>.*!^[MMR,`!0"C``4`
M(P$%`*,!!0#Q%SJ5"4?CZN?LT;]!$2+@!N0`"`)DHF"79@``@[;F]4$!;\!?
MM`$``@``````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E
M>&4``````"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0````````
M``!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``4$52
M3#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````
M````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/0D%,
M7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U0
M1$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````
M`````#$`````````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D``````!,
M1%],24)205)97U!!5$@`4UE35$5-```O=&UP`````%5315(`````55-%4DY!
M344``````````"4P,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R
M96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S
M=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````,`````````!0
M05(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,P```%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M```````````M90```````"TM````````5$U01$E2``!414U01$E2`%1%35``
M````5$U0``````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[
M,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL
M"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S
M971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@
M<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#
M(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D
M9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D
M<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A
M(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*
M<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D
M8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]
M"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M
M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`[
M"F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@
M/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D
M9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*
M7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO
M(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU3
M5VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E
M=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE
M(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!]
M(#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T
M7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O
M9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N
M86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%
M<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A
M<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;
M0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@
M;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@
M*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U
M=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U
M=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@
M)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH
M(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@
M:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U
M9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I
M<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B
M)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>
M*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE
M+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M
M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R
M8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK
M*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D
M=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D
M;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I
M;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF
M;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D
M(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@
M8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE0
M7TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C
M=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S
M=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S
M=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE
M+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2
M155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R
M;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*
M?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI
M9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L
M971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2
M.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]
M"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B
M.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R
M;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A
M<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M
M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK
M*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q
M<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("10
M2UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B
M.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO
M861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR
M96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E
M;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF
M("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\
M7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F
M:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A
M9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@
M(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@
M<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@
M9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@
M("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL
M92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K
M97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];
M7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64[
M"FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I
M;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F
M:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R
M(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\
M)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C
M:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T[
M"F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@
M>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@
M(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT
M*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M
M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L
M(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C
M86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C
M:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(
M12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#
M*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R
M(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE
M*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z
M.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%
M>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD
M"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&
M:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N
M86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E
M<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M
M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B
M)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C
M:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@
M)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER
M(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI
M(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?
M<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F
M:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S
M:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P
M.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S
M+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@
M)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES
M>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@
M)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B
M.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U
M;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP
M;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H
M;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE
M*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*
M?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M
M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[
M7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES
M=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T[
M"B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB
M.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]
M"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L
M:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?
M<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$
M?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!
M4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E
M;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P``
M````````0T%#2$4``(FKS>\``````1L#.^P````<````.(S__QP'``#DC?__
M!`$``-:.__\8`0``@H___X@!``#NC___P`$``!B1__\L`@``ZI+__Z`"``"Z
MD___Y`(``!J4__\0`P``4)3__S@#```*E?__?`,``!J5__^D`P``SI;___@#
M``#VEO__)`0``.B7__]P!```CIO__ZP$``#HF___W`0``#R<___\!```0IW_
M_T0%``!>G?__;`4``#">___4!0``7J/__WP&```@I?__P`8``-:E__]@!P``
M5KO__YP'``"RN___Q`<``+2\__\4"```;K[__V`(````````$``````````#
M>E(``7P!`1L,`@`0````&````-B,__\B``````<!`&P````L````MHW__ZP`
M````0@Y02(@$@0*)!I<20@P(`%J3"I0,E0YFD@B6$&C20M-"U$+50M9"P4+(
M#`)00M=$R4(.`$(-"($"B`2)!I((DPJ4#)4.EA"7$E+2UD33U-5$DPJ4#)4.
M0M-"U$+5```T````G````/*-__]L`````$(.L`%&B`2)!I((0@P(`$J!`@)*
M"L%"R`P"L`%"R4+20@X`0@L``&@```#4````)H[__RH!````0@[0`4:(!),*
M@0)"#`@`6HD&1LE2P4+(#`+0`4+30@X`0@T(@0*(!(D&DPI"D@A,E`P"0I4.
M`ES55`K)0M)"U$(+1I4.2,G2U-5(B0:2")0,E0Y$U-5"R4+2`'````!``0``
MY([__](!````0@YP4H@$B0:2"),*@0*4#)4.EQ*8%$(,"``"W@K!0L@,`G!"
MR4+20M-"U$+50M="V$(.`$(+<)80F1::&`)>"M9"V4+:1@M6UMG:1)80F1::
M&$;6V=I&EA"9%IH81M9"V4+:0````+0!``!"D/__T`````!"#E!,B`2)!I((
MDPJ4#)4.0@P(`%:!`@)B"@P"4$+!0LA"R4+20M-"U$+50@X`0@L````H````
M^`$``,Z0__]@`````$(.($*)!DR(!($"0@P(`&;(#`(@1,%"R5X.`"0````D
M`@```I'__S8`````2@X01(@$@0)"#`@`1,@,`A!"P5P.``!`````3`(``!"1
M__^Z`````$(.8$:!`H@$B09"#`@`2I((DPJ4#)4.`HX*#`)@0L%$R$+)0M)"
MTT+40M5"#@!""P```"0```"0`@``AI'__Q``````0@X01(@$@0)"#`@`0L@,
M`A!"P4(.``!0````N`(``&Z1__^T`0```$(.\`%*B`2)!I((DPJ7$D(,"`!@
M@0*4#)4.EA"8%)D6`DX*#`+P`4+!0LA"R4+20M-"U$+50M9"UT+80ME"#@!"
M"P`H````#`,``,Z2__\H`````$(.($:(!(D&@0)"#`@`4L@,`B!"P43)0@X`
M`$@````X`P``RI+___(`````0@Y`2H@$DPJ!`HD&D@A"#`@``IX*#`)`0L%"
MR$+)0M)"TT(.`$(+4@H,`D!"P4+(0LE"TD+32@X`1`LX````A`,``'"3__^F
M`P```$(.0$B(!(D&D@B3"D(,"`!*@0(#3@,*R`P"0$+!0LE"TD+34@X`1`L`
M```L````P`,``-J6__]:`````$(.,$2(!(D&0@P(`$J!`G@*P4+(#`(P0LE"
M#@!""P`<````\`,```27__]4`````$(.8$2(%($20@P(0````$0````0!```
M.)?__P8!````0@Y@4H@$DPJ4#)4.@0*)!I((EA"7$D(,"``"L@H,`F!"P4+(
M0LE"TD+30M1"U4+60M="#@!""R0```!8!```]I?__QP`````0@X01($"B`1"
M#`@`3L%"R`P"$$(.``!D````@`0``.J7___2`````$(.0$:(!)((DPI"#`@`
M8H$"3(D&1LE:R`P"0$+!0M)"TT(.`$0-"($"B`2)!I((DPI$E`P"1,@,`D!"
MU$+!0M)"TT3)2@X`1`T(@0*(!)((DPI$B0:4#*0```#H!```5)C__RX%````
M0@Z@`TR(!)((0@P(`&23"I0,@0*)!@*&E0Z6$)<2F!0#;`$*P4+(#`*@`T+6
M0M="V$+)0M)"TT+41-5"#@!""P)\F19&V6+5UM?85L@,`J`#0L%"TD+30M1$
MR4(.`$0-"($"B`2)!I((DPJ4#)4.EA"7$I@4F18#+`$*V4(+`^(`V4*9%D35
MUM?8V4J5#I80EQ*8%)D6`$````"0!0``VIS__\(!````0@Y00HD&5(@$DPJ4
M#($"D@B5#D(,"``#5`$*P4+(#`)00LE"TD+30M1"U4(.`$(+````6````-0%
M``!8GO__M@````!"#D!&B`2)!I((0@P(`&"!`FP*P4+(#`)`0LE"TD(.`$(+
M1),*;`K30@M.R`P"0$+30L%"R4320@X`1`T(@0*(!(D&D@A"DPH```!`````
M,`8``!2%__^J`0```$(.8$:!`H@$D@A"#`@`1HD&DPJ4#`,J`0K!0L@,`F!"
MR4+20M1$TT(.`$(+`````````#@```!T!@``;I[__X`5````1`[`!42(!$(,
M"`!>@0*)!I((DPH#/A4*P43(#`+`!43)1-)$TT0.`$(+`"0```"P!@``LK/_
M_UP`````0@X01(@$@0)"#`@``D[!0L@,`A!"#@!,````V`8``.:S__\"`0``
M`$(.4%"(!)((DPJ5#I80@0*)!I0,0@P(``)`EQ)&F!0"0M="V%`*P4+(#`)0
M0LE"TD+30M1"U4+60@X`0@L``$@````H!P``F+3__[H!````0@Y04H@$B0:2
M")0,E0Z7$H$"DPJ6$$(,"``#4`$*R`P"4$+!0LE"TD+30M1"U4+60M="#@!$
M"P`````D````=`<```:V__\:`````$(.$$2(!($"0@P(`$+(#`(00L%*#@``
M``````0````0`````0```$=.50``````!`````\`````````!````&````!^
M&O[*1D1/`'LB='EP92(Z(F1E8B(L(F]S(CHB=6)U;G1U(BPB;F%M92(Z(F=L
M:6)C(BPB=F5R<VEO;B(Z(C(N-#$M,75B=6YT=3$B+")A<F-H:71E8W1U<F4B
M.B)R:7-C=C8T(GT```0```!L````?AK^RD9$3P![(G1Y<&4B.B)D96(B+")O
M<R(Z(G5B=6YT=2(L(FYA;64B.B)L:6)P87(M<&%C:V5R+7!E<FPB+")V97)S
M:6]N(CHB,2XP-C,M,6)U:6QD,B(L(F%R8VAI=&5C='5R92(Z(G)I<V-V-C0B
M?0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````!`````````/D"````
M`````0`````````)`P````````$`````````$P,````````@`````````)BK
M````````(0`````````(`````````!D`````````H*L````````;````````
M``@`````````&@````````"HJP```````!P`````````"`````````#U_O]O
M`````/`"````````!0````````!8#0````````8`````````X`,````````*
M`````````+T$````````"P`````````8`````````!4`````````````````
M```#`````````,"M`````````@````````!8!0```````!0`````````!P``
M```````7`````````%`5````````!P````````!`$P````````@`````````
M:`<````````)`````````!@`````````'@`````````(`````````/O__V\`
M`````0``"`````#^__]O`````.`2````````____;P`````"`````````/#_
M_V\`````%A(```````#Y__]O``````L`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#__________P``````````L!H```````"P
M&@```````+`:````````L!H```````"P&@```````+`:````````L!H`````
M``"P&@```````+`:````````L!H```````"P&@```````+`:````````L!H`
M``````"P&@```````+`:````````L!H```````"P&@```````+`:````````
ML!H```````"P&@```````+`:````````L!H```````"P&@```````+`:````
M````L!H```````"P&@```````+`:````````L!H```````"P&@```````+`:
M````````L!H```````"P&@```````+`:````````L!H```````"P&@``````
M`+`:````````L!H```````"P&@```````+`:````````L!H```````"P&@``
M`````+`:````````L!H```````"P&@```````+`:````````L!H```````"P
M&@```````+`:````````L!H```````"P&@```````+`:````````L!H`````
M``"P&@```````+`:````````L!H```````"P&@```````+`:````````L*L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````I005(N<&T*````````````````````````
M````````````````````````````````````````````````````````````
M`$=#0SH@*%5B=6YT=2`Q-"XR+C`M,3=U8G5N='4Q*2`Q-"XR+C``064```!R
M:7-C=@`!6P````00!7)V-C1I,G`Q7VTR<#!?83)P,5]F,G`R7V0R<#)?8S)P
M,%]Z:6-S<C)P,%]Z:69E;F-E:3)P,%]Z;6UU;#%P,%]Z86%M;S%P,%]Z86QR
M<V,Q<#```"YS:'-T<G1A8@`N;F]T92YG;G4N8G5I;&0M:60`+FEN=&5R<``N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+FYO=&4N04))+71A9P`N;F]T92YP86-K
M86=E`"YP<F5I;FET7V%R<F%Y`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N<FES8W8N871T<FEB
M=71E<P``````````````````````````````````````````````````````
M``````````````````````````````````````````L````'`````@``````
M``"H`@```````*@"````````)`````````````````````0`````````````
M```````>`````0````(`````````S`(```````#,`@```````"$`````````
M```````````!````````````````````)@```/;__V\"`````````/`"````
M````\`(```````#L``````````0`````````"````````````````````#``
M```+`````@````````#@`P```````.`#````````>`D````````%`````@``
M``@`````````&``````````X`````P````(`````````6`T```````!8#0``
M`````+T$```````````````````!````````````````````0````/___V\"
M`````````!82````````%A(```````#*``````````0``````````@``````
M```"`````````$T```#^__]O`@````````#@$@```````.`2````````8```
M```````%`````@````@```````````````````!<````!`````(`````````
M0!,```````!`$P```````!`"````````!``````````(`````````!@`````
M````9@````0```!"`````````%`5````````4!4```````!8!0````````0`
M```5````"``````````8`````````&L````!````!@````````"P&@``````
M`+`:````````L`,``````````````````!``````````$`````````!P````
M`0````8`````````8!X```````!@'@```````%`R```````````````````$
M````````````````````=@````$````"`````````+!0````````L%``````
M``!X00``````````````````"````````````````````'X````!`````@``
M```````HD@```````"B2````````[`````````````````````0`````````
M``````````",`````0````(`````````&),````````8DP```````)P'````
M```````````````(````````````````````E@````<````"`````````+2:
M````````M)H````````@````````````````````!```````````````````
M`*0````'`````@````````#4F@```````-2:````````[```````````````
M``````0```````````````````"R````$`````,`````````F*L```````"8
MJP````````@````````````````````(``````````@`````````P0````X`
M```#`````````*"K````````H*L````````(````````````````````"```
M```````(`````````,T````/`````P````````"HJP```````*BK````````
M"`````````````````````@`````````"`````````#9````!@````,`````
M````L*L```````"PJP```````!`"````````!0`````````(`````````!``
M````````X@````$````#`````````,"M````````P*T```````!``@``````
M````````````"``````````(`````````.<````!`````P``````````L```
M``````"P````````4`````````````````````@```````````````````#M
M````"`````,`````````4+````````!0L````````"@`````````````````
M```(````````````````````\@````$````P````````````````````4+``
M```````F`````````````````````0`````````!`````````/L````#``!P
M`````````````````````':P````````9@````````````````````$`````
M```````````````!`````P````````````````````````#<L`````````T!
>```````````````````!````````````````````
